@@ -10,9 +10,8 @@ import sys
 import sysconfig
 import subprocess
 
-from distutils.sysconfig import customize_compiler
+from distutils.sysconfig import customize_compiler, get_python_lib
 import distutils.command.build_ext
-from distutils.dep_util import newer, newer_group
 
 import PyQt5.QtCore
 
@@ -83,6 +82,8 @@ class build_ext(distutils.command.build_ext.build_ext):
          'override Qt include directory'),
         ('qt-library-dir=', None,
          'override Qt library directory'),
+        ('qt-libinfix=', None,
+         'override Qt infix setting'),
         ]
 
     def initialize_options(self):
@@ -93,20 +94,7 @@ class build_ext(distutils.command.build_ext.build_ext):
         self.qmake_exe = None
         self.qt_include_dir = None
         self.qt_library_dir = None
-
-    def _get_sip_output_list(self, sbf):
-        '''
-        Parse the sbf file specified to extract the name of the generated source
-        files. Make them absolute assuming they reside in the temp directory.
-        '''
-        for line in open(sbf):
-            key, value = line.split('=', 1)
-            if key.strip() == 'sources':
-                out = []
-                for o in value.split():
-                    out.append(os.path.join(self.build_temp, o))
-                return out
-        raise RuntimeError('cannot parse SIP-generated "%s"' % sbf)
+        self.qt_libinfix = None
 
     def _get_sip_exe(self, build_cmd):
         """Get exe for sip. Sources are:
@@ -166,6 +154,32 @@ class build_ext(distutils.command.build_ext.build_ext):
                 [self._get_qmake(build_cmd), '-query', 'QT_INSTALL_LIBS'])
             )
 
+    def _get_qt_libinfix(self, build_cmd):
+        """Get QT_LIBINFIX setting.
+
+        This is not much fun, as we have to try to find qconfig.pri,
+        and parse it.
+        """
+
+        infix = build_cmd.qt_libinfix
+        if infix is not None:
+            return infix
+        if 'QT_LIBINFIX' in os.environ:
+            return os.environ['QT_LIBINFIX']
+
+        # use this to find location of qconfig file
+        archdir = read_command_output(
+            [self._get_qmake(build_cmd), '-query', 'QT_INSTALL_ARCHDATA'])
+        qconfig = os.path.join(archdir, 'mkspecs', 'qconfig.pri')
+
+        libinfix = ''
+        for line in open(qconfig):
+            p = [x.strip() for x in line.split('=')]
+            if p[0] == 'QT_LIBINFIX':
+                libinfix = p[1]
+
+        return libinfix
+
     def _is_qt_framework(self, build_cmd):
         """Is the Qt a framework?"""
         return os.path.exists(
@@ -207,6 +221,8 @@ class build_ext(distutils.command.build_ext.build_ext):
         # Add the SIP and Qt include directories to the include path
         extension.include_dirs += [sip_inc_dir] + indirs
 
+        libinfix = self._get_qt_libinfix(build_cmd)
+
         # link against libraries
         if extension.language == 'c++':
             extension.include_dirs += self._get_cpp_includes(build_cmd)
@@ -215,10 +231,10 @@ class build_ext(distutils.command.build_ext.build_ext):
                 # Mac OS framework
                 extension.extra_link_args = [
                     '-F', os.path.join(lib_dir),
-                    '-framework', 'QtGui',
-                    '-framework', 'QtCore',
-                    '-framework', 'QtXml',
-                    '-framework', 'QtWidgets',
+                    '-framework', 'QtGui'+libinfix,
+                    '-framework', 'QtCore'+libinfix,
+                    '-framework', 'QtXml'+libinfix,
+                    '-framework', 'QtWidgets'+libinfix,
                     '-Wl,-rpath,@executable_path/Frameworks',
                     '-Wl,-rpath,' + lib_dir
                     ]
@@ -227,7 +243,11 @@ class build_ext(distutils.command.build_ext.build_ext):
                     ]
             else:
                 extension.libraries = [
-                    'Qt5Gui', 'Qt5Core', 'Qt5Xml', 'Qt5Widgets']
+                    'Qt5Gui'+libinfix,
+                    'Qt5Core'+libinfix,
+                    'Qt5Xml'+libinfix,
+                    'Qt5Widgets'+libinfix,
+                ]
             extension.library_dirs = [lib_dir]
 
             # may cause problems with compilers which don't allow this
@@ -254,26 +274,35 @@ class build_ext(distutils.command.build_ext.build_ext):
         generated_sources = []
 
         for sip in sip_sources:
-            # Use the sbf file as dependency check
-            sipbasename = os.path.basename(sip)
-            sbf = os.path.join(self.build_temp,
-                               replace_suffix(sipbasename, '.sbf'))
-            if newer_group([sip]+depends, sbf) or self.force:
-                self._sip_compile(sip_exe, sip_dir, sip, sbf)
-            out = self._get_sip_output_list(sbf)
+            sip_basename = os.path.basename(sip)[:-4]
+            sip_builddir = os.path.join(self.build_temp, 'sip-' + sip_basename)
+            if not os.path.exists(sip_builddir) or self.force:
+                os.makedirs(sip_builddir, exist_ok=True)
+                self._sip_compile(sip_exe, sip_dir, sip, sip_builddir)
+            out = [
+                os.path.join(sip_builddir, fn)
+                for fn in sorted(os.listdir(sip_builddir))
+                if fn.endswith(".cpp")
+            ]
             generated_sources.extend(out)
 
         return generated_sources + other_sources
 
-    def _sip_compile(self, sip_exe, sip_dir, source, sbf):
+    def _sip_compile(self, sip_exe, sip_dir, source, sip_builddir):
         """Compile sip file to sources."""
+        if 'sip5' in sip_exe:
+            pyqt5_include_dir = os.path.join(get_python_lib(plat_specific=1),
+                                             'PyQt5', 'bindings')
+            self.spawn(['sip-module', '--target-dir', sip_builddir,
+                        '--sip-h', 'PyQt5.sip'])
+        else:
+            pyqt5_include_dir = os.path.join(sip_dir, 'PyQt5')
         self.spawn(
             [
                 sip_exe,
-                '-c', self.build_temp
+                '-c', sip_builddir
             ] + SIP_FLAGS.split() + [
-                '-I', os.path.join(sip_dir, 'PyQt5'),
-                '-b', sbf,
+                '-I', pyqt5_include_dir,
                 source
             ]
         )
