@@ -20,7 +20,7 @@ from __future__ import division, print_function
 import os
 import os.path
 
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import setting
 from .. import utils
 from .. import document
@@ -29,7 +29,7 @@ from .veuszdialog import VeuszDialog
 
 def _(text, disambiguation=None, context='ExportDialog'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 # formats which can have multiple pages
 multipageformats = set(('ps', 'pdf'))
@@ -62,7 +62,7 @@ class ExportDialog(VeuszDialog):
         self.updatePagePages()
 
         # change 'Save' button to 'Export'
-        self.buttonBox.button(qt4.QDialogButtonBox.Save).setText(_('Export'))
+        self.buttonBox.button(qt.QDialogButtonBox.Save).setText(_('Export'))
 
         # these are mappings between filetypes and radio buttons
         self.fmtradios = dict([(f, getattr(self, r)) for f, r in formatradio])
@@ -70,7 +70,7 @@ class ExportDialog(VeuszDialog):
 
         # get allowed types (some formats are disabled if no helper)
         docfmts = set()
-        for types, descr in document.Export.getFormats():
+        for types, descr in document.AsyncExport.getFormats():
             docfmts.update(types)
         # disable type if not allowed
         for fmt, radio in citems(self.fmtradios):
@@ -102,7 +102,7 @@ class ExportDialog(VeuszDialog):
         elif eloc == 'cwd':
             self.dirname = cgetcwd()
         else: # 'prev'
-            self.dirname = setdb.get('dirname_export', qt4.QDir.homePath())
+            self.dirname = setdb.get('dirname_export', qt.QDir.homePath())
 
         # set default filename
         ext = setdb.get('export_format', 'pdf')
@@ -125,7 +125,7 @@ class ExportDialog(VeuszDialog):
         dpis = ('72', '75', '90', '96', '100', '150', '200', '300')
         for cntrl in self.exportDPI, self.exportDPISVG, self.exportDPIPDF:
             cntrl.addItems(dpis)
-            cntrl.setValidator(qt4.QIntValidator(10, 10000, self))
+            cntrl.setValidator(qt.QIntValidator(10, 10000, self))
         self.exportDPI.setEditText(str(setdb['export_DPI']))
         self.exportDPISVG.setEditText(str(setdb['export_DPI_SVG']))
         self.exportDPIPDF.setEditText(str(setdb['export_DPI_PDF']))
@@ -139,9 +139,9 @@ class ExportDialog(VeuszDialog):
         self.fmtradios[ext].click()
 
         # regexp for comma separated ranges
-        valre = qt4.QRegExp(
+        valre = qt.QRegExp(
             r'^[0-9]+(\s*-\s*[0-9]+)?(\s*,\s*[0-9]+(\s*-\s*[0-9]+)?)*$')
-        valid = qt4.QRegExpValidator(valre, self)
+        valid = qt.QRegExpValidator(valre, self)
         self.editPagePages.setValidator(valid)
 
         # set page mode
@@ -199,15 +199,15 @@ class ExportDialog(VeuszDialog):
         setdb = setting.settingdb
 
         # File types we can export to in the form ([extensions], Name)
-        fd = qt4.QFileDialog(self, _('Export page'))
+        fd = qt.QFileDialog(self, _('Export page'))
 
         filename = self.editFileName.text()
         dirname = os.path.dirname(self.editFileName.text())
         fd.setDirectory(dirname if dirname else self.dirname)
 
-        fd.setFileMode(qt4.QFileDialog.AnyFile)
-        fd.setAcceptMode(qt4.QFileDialog.AcceptSave)
-        fd.setOptions(qt4.QFileDialog.DontConfirmOverwrite)
+        fd.setFileMode(qt.QFileDialog.AnyFile)
+        fd.setAcceptMode(qt.QFileDialog.AcceptSave)
+        fd.setOptions(qt.QFileDialog.DontConfirmOverwrite)
 
         # Create a mapping between a format string and extensions
         filtertoext = {}
@@ -216,7 +216,7 @@ class ExportDialog(VeuszDialog):
         filters = []
         # a list of extensions which are allowed
         validextns = []
-        formats = document.Export.getFormats()
+        formats = document.AsyncExport.getFormats()
         for extns, name in formats:
             extensions = " ".join(["*." + item for item in extns])
             # join eveything together to make a filter string
@@ -235,7 +235,7 @@ class ExportDialog(VeuszDialog):
         if os.path.isdir(dirname):
             fd.selectFile(filename)
 
-        if fd.exec_() == qt4.QDialog.Accepted:
+        if fd.exec_() == qt.QDialog.Accepted:
             # convert filter to extension
             filterused = str(fd.selectedNameFilter())
             chosenext = filtertoext[filterused][0]
@@ -282,7 +282,7 @@ class ExportDialog(VeuszDialog):
         text = '%i-%i' % (1, npages)
         self.editPagePages.setText(text)
 
-    @qt4.pyqtSlot()
+    @qt.pyqtSlot()
     def clearLabel(self):
         """Clear label.
         Defined as a slot to work around PyQt C++ object deleted bug. """
@@ -291,32 +291,34 @@ class ExportDialog(VeuszDialog):
     def showMessage(self, text):
         """Show a message in a label, clearing after a time."""
         self.labelStatus.setText(text)
-        qt4.QTimer.singleShot(3000, self.clearLabel)
+        qt.QTimer.singleShot(3000, self.clearLabel)
 
     def updateExportBackground(self, colorname):
         """Update color on export background."""
-        pixmap = qt4.QPixmap(16, 16)
+        pixmap = qt.QPixmap(16, 16)
         col = self.document.evaluate.colors.get(colorname)
         pixmap.fill(col)
 
         # update button (storing color in button itself - what fun!)
-        self.exportBackgroundButton.setIcon(qt4.QIcon(pixmap))
+        self.exportBackgroundButton.setIcon(qt.QIcon(pixmap))
         self.exportBackgroundButton.iconcolor = colorname
 
     def slotExportBackgroundClicked(self):
         """Button clicked to change background."""
         qcolor = self.document.evaluate.colors.get(
             self.exportBackgroundButton.iconcolor)
-        color = qt4.QColorDialog.getColor(
+        color = qt.QColorDialog.getColor(
             qcolor,
             self,
             "Choose color",
-            qt4.QColorDialog.ShowAlphaChannel )
+            qt.QColorDialog.ShowAlphaChannel )
         if color.isValid():
             self.updateExportBackground(utils.extendedColorFromQColor(color))
 
     def getPagePages(self):
         """Get list of entered pages."""
+        visible = set(self.document.getVisiblePages())
+
         txt = self.editPagePages.text()
         parts = txt.split(',')
         pages = []
@@ -325,9 +327,13 @@ class ExportDialog(VeuszDialog):
             try:
                 if p.find('-')>=0:
                     rng = p.split('-')
-                    pages += list(range(int(rng[0])-1, int(rng[1])))
+                    for pg in range(int(rng[0])-1, int(rng[1])):
+                        if pg in visible:
+                            pages.append(pg)
                 else:
-                    pages.append(int(p)-1)
+                    pg = int(p)-1
+                    if pg in visible:
+                        pages.append(pg)
             except ValueError:
                 # convertsion error
                 raise RuntimeError(_('Error: invalid list of pages'))
@@ -340,8 +346,8 @@ class ExportDialog(VeuszDialog):
     def accept(self):
         """Do the export"""
 
-        if self.document.getNumberPages() == 0:
-            self.showMessage(_('Error: no pages in document'))
+        if not self.document.getVisiblePages():
+            self.showMessage(_('Error: no visible pages in document'))
             return
 
         filename = self.editFileName.text()
@@ -354,10 +360,14 @@ class ExportDialog(VeuszDialog):
                 _('Error: page name or number must be in filename'))
             return
 
+        # add extension to filename if missing
+        if not os.path.splitext(filename)[1]:
+            filename += '.' + self.formatselected
+
         if self.pageselected == 'single':
             pages = [self.mainwindow.plot.getPageNumber()]
         elif self.pageselected == 'all':
-            pages = list(range(self.document.getNumberPages()))
+            pages = self.document.getVisiblePages()
         elif self.pageselected == 'pages':
             try:
                 pages = self.getPagePages()
@@ -384,15 +394,13 @@ class ExportDialog(VeuszDialog):
             try:
                 text = cntrl.currentText()
                 valid = cntrl.validator().validate(text, 0)[0]
-                if valid == qt4.QValidator.Acceptable:
+                if valid == qt.QValidator.Acceptable:
                     setdb[setn] = int(text)
             except ValueError:
                 pass
 
-        export = document.Export(
+        export = document.AsyncExport(
             self.document,
-            '',    # filename
-            [0],   # page numbers
             bitmapdpi=setdb['export_DPI'],
             pdfdpi=setdb['export_DPI_PDF'],
             antialias=setdb['export_antialias'],
@@ -405,62 +413,50 @@ class ExportDialog(VeuszDialog):
 
         def _overwriteQuestion(filename):
             """Ask user whether file can be overwritten."""
-            retn = qt4.QMessageBox.question(
+            retn = qt.QMessageBox.question(
                 self,
                 _("Overwrite file?"),
                 _("The file %s already exists") % os.path.basename(filename),
-                qt4.QMessageBox.Save | qt4.QMessageBox.Cancel,
-                qt4.QMessageBox.Cancel)
-            return retn == qt4.QMessageBox.Save
+                qt.QMessageBox.Save | qt.QMessageBox.Cancel,
+                qt.QMessageBox.Cancel)
+            return retn == qt.QMessageBox.Save
 
         # count exported pages (in list so can be modified in function)
         pagecount = [0]
-        def _checkAndExport():
+        def _checkAndExport(fname, pages):
             """Check whether file exists and export if ok."""
-            if os.path.exists(export.filename):
+            if os.path.exists(fname):
                 if not setdb['export_overwrite']:
-                    if not _overwriteQuestion(export.filename):
+                    if not _overwriteQuestion(fname):
                         return
 
             # show busy cursor
-            qt4.QApplication.setOverrideCursor(qt4.QCursor(qt4.Qt.WaitCursor))
+            #qt.QApplication.setOverrideCursor(qt.QCursor(qt.Qt.WaitCursor))
             # delete file if already exists
             try:
-                os.unlink(export.filename)
+                os.unlink(fname)
             except EnvironmentError:
                 pass
 
-            try:
-                # actually do the export
-                export.export()
-                pagecount[0] += len(export.pagenumbers)
-            except (RuntimeError, EnvironmentError) as e:
-                # errors from the export
-                if isinstance(e, EnvironmentError):
-                    msg = cstrerror(e)
-                else:
-                    msg = cstr(e)
-                qt4.QApplication.restoreOverrideCursor()
-                qt4.QMessageBox.critical(
-                    self, _("Error - Veusz"),
-                    _("Error exporting to file '%s'\n\n%s") %
-                    (export.filename, msg))
-            else:
-                qt4.QApplication.restoreOverrideCursor()
+            # actually do the export
+            export.add(fname, pages)
+            pagecount[0] += len(pages)
+
+            ext = os.path.splitext(fname)[1]
+            if ext:
+                utils.feedback.exportcts[ext] += 1
 
         if self.isMultiFile() or len(pages)==1:
             # write pages to multiple files
             for page in pages:
                 pagename = self.document.getPage(page).name
-                export.pagenumbers = [page]
 
                 pg = page+1
                 fname = filename.replace('%PAGE%', str(pg))
                 fname = fname.replace('%PAGE00%', '%02i' % pg)
                 fname = fname.replace('%PAGE000%', '%03i' % pg)
                 fname = fname.replace('%PAGENAME%', pagename)
-                export.filename = fname
-                _checkAndExport()
+                _checkAndExport(fname, [page])
         else:
             # write page/pages to single file
             fname = filename.replace('%PAGE%', _('none'))
@@ -468,18 +464,43 @@ class ExportDialog(VeuszDialog):
             fname = fname.replace('%PAGE000%', _('none'))
             fname = fname.replace('%PAGENAME%', _('none'))
 
-            export.pagenumbers = pages
-            export.filename = fname
-            _checkAndExport()
+            _checkAndExport(fname, pages)
 
         dirname = os.path.dirname(filename)
         if dirname:
             setting.settingdb['dirname_export'] = dirname
 
         # format feedback
-        ext = os.path.splitext(export.filename)[1]
-        if ext:
-            utils.feedback.exportcts[ext] += 1
+        self.showMessage(_('Processing...'))
 
-        if pagecount[0] > 0:
-            self.showMessage(_('Exported %i page(s)') % pagecount[0])
+        self.buttonBox.button(qt.QDialogButtonBox.Close).setEnabled(False)
+        self.buttonBox.button(qt.QDialogButtonBox.Save).setEnabled(False)
+
+        def checkDone():
+            """Check whether exporting has finished."""
+            if not export.haveDone():
+                return
+            try:
+                export.finish()
+            except (RuntimeError, EnvironmentError) as e:
+                # errors from the export
+                if isinstance(e, EnvironmentError):
+                    msg = cstrerror(e)
+                else:
+                    msg = cstr(e)
+                #qt.QApplication.restoreOverrideCursor()
+                qt.QMessageBox.critical(
+                    self, _("Error - Veusz"),
+                    _("Error exporting to file '%s'\n\n%s") %
+                    (fname, msg))
+            else:
+                if pagecount[0] > 0:
+                    self.showMessage(_('Exported %i page(s)') % pagecount[0])
+
+            self.buttonBox.button(qt.QDialogButtonBox.Close).setEnabled(True)
+            self.buttonBox.button(qt.QDialogButtonBox.Save).setEnabled(True)
+            self.checktimer.stop()
+
+        self.checktimer = qt.QTimer(self)
+        self.checktimer.timeout.connect(checkDone)
+        self.checktimer.start(20)
