@@ -29,7 +29,7 @@ import os.path
 import numpy as N
 
 from ..compat import cbasestr
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import setting
 from .. import embed
 from .. import plugins
@@ -42,7 +42,7 @@ from . import export
 
 def _(text, disambiguation=None, context='CommandInterface'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 def registerImportCommand(name, method, filenamearg=0):
     """Add command to command interface."""
@@ -50,7 +50,7 @@ def registerImportCommand(name, method, filenamearg=0):
     CommandInterface.import_commands.append(name)
     CommandInterface.import_filenamearg[name] = filenamearg
 
-class CommandInterface(qt4.QObject):
+class CommandInterface(qt.QObject):
     """Class provides command interface."""
 
     # commands which are safe in any script (excluding import commands)
@@ -59,6 +59,7 @@ class CommandInterface(qt4.QObject):
         'Add',
         'AddCustom',
         'AddImportPath',
+        'CurrentPath',
         'CloneWidget',
         'CreateHistogram',
         'DatasetPlugin',
@@ -95,7 +96,7 @@ class CommandInterface(qt4.QObject):
         'TagDatasets',
         'To',
         'WidgetType',
-        ]
+    ]
 
     # commands for importing data
     import_commands = []
@@ -107,11 +108,11 @@ class CommandInterface(qt4.QObject):
         'Export',
         'Print',
         'Save',
-        ]
+    ]
 
     def __init__(self, document):
         """Initialise the interface."""
-        qt4.QObject.__init__(self)
+        qt.QObject.__init__(self)
 
         self.document = document
         self.currentwidget = self.document.basewidget
@@ -122,7 +123,7 @@ class CommandInterface(qt4.QObject):
 
         self.Root = embed.WidgetNode(self, 'widget', '/')
 
-    @qt4.pyqtSlot()
+    @qt.pyqtSlot()
     def slotWipedDoc(self):
         """When the document is wiped, we change to the root widget."""
         self.To('/')
@@ -278,6 +279,10 @@ class CommandInterface(qt4.QObject):
             print(_('Constructed histogram of "%s", creating datasets'
                     ' "%s" and "%s"') % (inexpr, outbinsds, outvalsds))
 
+    def CurrentPath(self):
+        """Return the current path (set by To())."""
+        return self.currentwidget.path
+
     def DatasetPlugin(self, pluginname, fields, datasetnames={}):
         """Use a dataset plugin.
 
@@ -769,13 +774,19 @@ class CommandInterface(qt4.QObject):
         except TypeError:
             pages = [page]
 
-        e = export.Export(
-            self.document, filename, pages, color=color,
-            bitmapdpi=dpi, antialias=antialias,
-            quality=quality, backcolor=backcolor,
+        e = export.AsyncExport(
+            self.document,
+            color=color,
+            bitmapdpi=dpi,
+            antialias=antialias,
+            quality=quality,
+            backcolor=backcolor,
             pdfdpi=pdfdpi,
-            svgdpi=svgdpi, svgtextastext=svgtextastext)
-        e.export()
+            svgdpi=svgdpi,
+            svgtextastext=svgtextastext
+        )
+        e.add(filename, pages)
+        e.finish()
 
     def Rename(self, widget, newname):
         """Rename the widget with the path given to the new name.
