@@ -32,16 +32,16 @@ import io
 
 import numpy as N
 
-from ..compat import czip, crange, citems, cbasestr
+from ..compat import czip, crange, citems, cbasestr, cpy3
 from . import widgetfactory
 
 from .. import datasets
 from .. import plugins
-from .. import qtall as qt4
+from .. import qtall as qt
 
 def _(text, disambiguation=None, context="Operations"):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 ###############################################################################
 # Setting operations
@@ -1176,7 +1176,8 @@ class OperationLoadStyleSheet(OperationMultiple):
         # fire up interpreter to read file
         interpreter = commandinterpreter.CommandInterpreter(document)
         try:
-            interpreter.runFile( io.open(self.filename, 'rU',
+            mode = 'r' if cpy3 else 'rU'
+            interpreter.runFile( io.open(self.filename, mode,
                                          encoding='utf8') )
         except:
             document.batchHistory(None)
