@@ -66,8 +66,9 @@ def findOnPath(cmd):
     path = os.getenv('PATH', os.path.defpath)
     pathparts = path.split(os.path.pathsep)
     for dirname in pathparts:
+        dirname = dirname.strip('"')
         cmdtry = os.path.join(dirname, cmd)
-        if os.path.isfile(cmdtry):
+        if os.path.isfile(cmdtry) and os.access(cmdtry, os.X_OK):
             return cmdtry
     return None
 
@@ -147,8 +148,15 @@ class Embedded(object):
             cls.sockfamily = socket.AF_UNIX
             sock, socket2 = socket.socketpair(cls.sockfamily,
                                               socket.SOCK_STREAM)
+
+            # socket is closed on popen in Python 3.4+ without this (PEP 446)
+            try:
+                os.set_inheritable(socket2.fileno(), True)
+            except AttributeError:
+                pass
+
             sendtext = 'unix %i\n' % socket2.fileno()
-            cls.socket2 = socket2
+            cls.socket2 = socket2    # prevent socket being destroyed
             waitaccept = False
 
         else:
@@ -217,6 +225,9 @@ class Embedded(object):
             else:
                 possiblecommands += [[
                     '/Applications/Veusz.app/Contents/MacOS/Veusz' ]]
+                possiblecommands += [[
+                    os.path.expanduser('~/Applications/Veusz.app/Contents/MacOS/Veusz')]]
+
 
         for cmd in possiblecommands:
             # only try to run commands that exist as error handling
