@@ -32,11 +32,11 @@ try:
     from ..helpers import qtloops
 except ImportError:
     pass
-from .. import qtall as qt4
+from .. import qtall as qt
 
 def _(text, disambiguation=None, context='DatasetPlugin'):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 # add an instance of your class to this list to be registered
 datasetpluginregistry = []
@@ -651,6 +651,34 @@ class AddDatasetPlugin(_OneOutputDatasetPlugin):
         self.dsout.update(data = ds_in.data + fields['value'],
                           serr=ds_in.serr, perr=ds_in.perr, nerr=ds_in.nerr)
 
+class ReverseDatasetPlugin(_OneOutputDatasetPlugin):
+    """Dataset plugin to reverse datasets."""
+
+    menu = (_('Other'), _('Reverse'),)
+    name = 'Reverse'
+    description_short = _('Reverse dataset')
+    description_full = description_short 
+
+    def __init__(self):
+        """Define fields."""
+        self.fields = [
+            field.FieldDataset('ds_in', _('Input dataset')),
+            field.FieldDataset('ds_out', _('Output dataset name')),
+            ]
+
+    def updateDatasets(self, fields, helper):
+        """Do reverse of dataset."""
+
+        ds_in = helper.getDataset(fields['ds_in'])
+
+        data, serr, perr, nerr = ds_in.data, ds_in.serr, ds_in.perr, ds_in.nerr
+        data = data[::-1]
+        if serr is not None: serr = serr[::-1]
+        if perr is not None: perr = perr[::-1]
+        if nerr is not None: nerr = nerr[::-1]
+
+        self.dsout.update(data=data, serr=serr, perr=perr, nerr=nerr)
+
 class ConcatenateDatasetPlugin(_OneOutputDatasetPlugin):
     """Dataset plugin to concatenate datasets."""
 
@@ -1112,6 +1140,34 @@ class SubtractMinimumDatasetPlugin(_OneOutputDatasetPlugin):
         self.dsout.update(
             data=data, serr=dsin.serr, perr=dsin.perr, nerr=dsin.nerr)
 
+class SubtractMaximumDatasetPlugin(_OneOutputDatasetPlugin):
+    """Dataset plugin to subtract minimum from dataset."""
+
+    menu = (_('Subtract'), _('Maximum'),)
+    name = 'Subtract Maximum'
+    description_short = _('Subtract maximum from dataset')
+    description_full = _('Subtract the maximum value from a dataset')
+
+    def __init__(self):
+        """Define fields."""
+        self.fields = [
+            field.FieldDataset('ds_in', _('Input dataset 1')),
+            field.FieldDataset('ds_out', _('Output dataset name')),
+            ]
+
+    def updateDatasets(self, fields, helper):
+        """Do subtraction of dataset."""
+
+        dsin = helper.getDataset(fields['ds_in'])
+
+        data = dsin.data
+        filtered = data[N.isfinite(data)]
+        if len(filtered) != 0:
+            data = data - filtered.max()
+
+        self.dsout.update(
+            data=data, serr=dsin.serr, perr=dsin.perr, nerr=dsin.nerr)
+
 class MultiplyDatasetsPlugin(_OneOutputDatasetPlugin):
     """Dataset plugin to multiply two or more datasets."""
 
@@ -2130,6 +2186,7 @@ datasetpluginregistry += [
     SubtractDatasetPlugin,
     SubtractMeanDatasetPlugin,
     SubtractMinimumDatasetPlugin,
+    SubtractMaximumDatasetPlugin,
     MultiplyDatasetPlugin,
     MultiplyDatasetsPlugin,
     DivideDatasetsPlugin,
@@ -2142,6 +2199,7 @@ datasetpluginregistry += [
     LogPlugin,
     ExpPlugin,
 
+    ReverseDatasetPlugin,
     ConcatenateDatasetPlugin,
     InterleaveDatasetPlugin,
 
