@@ -23,17 +23,18 @@ import sys
 import datetime
 
 import numpy as N
-from .. import qtall as qt4
+from .. import qtall as qt
 
 def _(text, disambiguation=None, context="Preferences"):
     """Translate text."""
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 # default values to some settings in case the user does not have these
 defaultValues = {
     # export options
     'export_DPI': 100,
     'export_DPI_PDF': 150,
+    'export_DPI_SVG': 96,
     'export_color': True,
     'export_antialias': True,
     'export_quality': 85,
@@ -79,12 +80,16 @@ defaultValues = {
     'export_template_single': '%DOCNAME%',
     'export_template_multi': '%DOCNAME%_%PAGE00%',
 
+    # add import paths
+    'docfile_addimportpaths': True,
+
     # ask tutorial before?
     'ask_tutorial': False,
 
     # log picked points to clipboard or to console
     'picker_to_clipboard': False,
     'picker_to_console': True,
+    'picker_sig_figs': 5,
 
     # add these directories to the python path (colon-separated)
     'external_pythonpath': '',
@@ -107,7 +112,11 @@ defaultValues = {
     # (packagers, please don't disable here but in veusz/setting/feedback.py)
     'feedback_disabled': False,
     'feedback_asked_user': False,
-    }
+
+    # locations considered secure to load
+    'secure_dirs': [],
+    'secure_unsaved': True,
+}
 
 class _SettingDB(object):
     """A class which provides access to a persistant settings database.
@@ -145,14 +154,14 @@ class _SettingDB(object):
         if val[0]:
             default = self.color_defaults[name]
             if default == 'LightBase':
-                base = qt4.qApp.palette().color(qt4.QPalette.Base)
+                base = qt.qApp.palette().color(qt.QPalette.Base)
                 if base.value() < 127:
-                    base = qt4.QColor(qt4.Qt.white)
+                    base = qt.QColor(qt.Qt.white)
                 return base
 
-            return qt4.QColor(default)
+            return qt.QColor(default)
         else:
-            return qt4.QColor(val[1])
+            return qt.QColor(val[1])
 
     def readSettings(self):
         """Read the settings using QSettings.
@@ -165,7 +174,7 @@ class _SettingDB(object):
         We should probably check for this
         """
 
-        s = qt4.QSettings(self.domain, self.product)
+        s = qt.QSettings(self.domain, self.product)
 
         for key in s.childKeys():
             val = s.value(key)
@@ -193,7 +202,7 @@ class _SettingDB(object):
         This is called by the mainwindow on close
         """
 
-        s = qt4.QSettings(self.domain, self.product)
+        s = qt.QSettings(self.domain, self.product)
 
         # write each entry, keeping track of which ones haven't been written
         cleankeys = []
@@ -242,12 +251,12 @@ def updateUILocale():
     global uilocale
 
     if settingdb['ui_english']:
-        uilocale = qt4.QLocale.c()
+        uilocale = qt.QLocale.c()
     else:
-        uilocale = qt4.QLocale.system()
-    uilocale.setNumberOptions(qt4.QLocale.OmitGroupSeparator)
+        uilocale = qt.QLocale.system()
+    uilocale.setNumberOptions(qt.QLocale.OmitGroupSeparator)
 
-    qt4.QLocale.setDefault(uilocale)
+    qt.QLocale.setDefault(uilocale)
 
 def ui_floattostring(f, maxdp=14):
     """Convert float to string with more precision."""
