@@ -19,6 +19,7 @@
 from __future__ import division
 import re
 import math
+import numpy as N
 
 from . import dates
 
@@ -51,6 +52,7 @@ def localeFormat(totfmt, args, locale=None):
                 i += 1
             except IndexError:
                 raise TypeError("Not enough arguments for format string")
+            s = s.replace('-', u'\u2212')
             if locale is not None and code in 'eEfFgG':
                 s = s.replace('.', locale.decimalPoint())
 
@@ -94,6 +96,10 @@ def formatSciNotation(num, formatargs, locale=None):
     locale is a QLocale object
     """
 
+    # handle nan, inf, -inf
+    if not N.isfinite(num):
+        return str(num)
+
     # create an initial formatting string
     if formatargs:
         formatstr = '%' + formatargs + 'e'
@@ -228,8 +234,7 @@ def formatNumber(num, formatstr, locale=None):
         else:
             # standard C formatting
             try:
-                out = localeFormat('%' + farg + ftype, (num,),
-                                   locale=locale)
+                out = localeFormat('%' + farg + ftype, (num,), locale=locale)
             except:
                 out = _formaterror
 
@@ -238,4 +243,3 @@ def formatNumber(num, formatstr, locale=None):
         formatstr = formatstr[match.end():]
 
     return ''.join(outitems)
-
