@@ -584,6 +584,10 @@ def allNotNone(*items):
     """Are all the items not None."""
     return not any((x is None for x in items))
 
+def anyNone(*items):
+    """Are any items None."""
+    return any((x is None for x in items))
+
 def findOnPath(cmd):
     """Find a command on the system path, or None if does not exist."""
     path = os.getenv('PATH', os.path.defpath)
@@ -638,3 +642,15 @@ class SvgWidgetFixedAspect(qt.QWidget):
             top = 0
 
         self.renderer.render(painter, qt.QRectF(left, top, outw, outh))
+
+class OverrideCursor:
+    """A context manager to handle changing the mouse cursor temporarily."""
+
+    def __init__(self, cursor=qt.Qt.WaitCursor):
+        self.cursor = cursor
+
+    def __enter__(self):
+        qt.QApplication.setOverrideCursor(qt.QCursor(self.cursor))
+
+    def __exit__(self, typ, value, traceback):
+        qt.QApplication.restoreOverrideCursor()
