@@ -22,7 +22,7 @@ from __future__ import division
 import numpy as N
 
 from ..compat import crange, cstr
-from .. import qtall as qt4
+from .. import qtall as qt
 from .. import setting
 from .. import document
 
@@ -30,7 +30,7 @@ from . import axis
 
 def _(text, disambiguation=None, context='FunctionAxis'):
     '''Translate text.'''
-    return qt4.QCoreApplication.translate(context, text, disambiguation)
+    return qt.QCoreApplication.translate(context, text, disambiguation)
 
 class AxisError(RuntimeError):
     pass
@@ -71,7 +71,10 @@ def solveFunction(function, vals, mint=None, maxt=None):
         xvals = N.hstack(( xvals[xvals < maxt], maxt ))
 
     # yvalue in correct shape
-    yvals = function(xvals) + N.zeros(len(xvals))
+    try:
+        yvals = function(xvals) + N.zeros(len(xvals))
+    except Exception as e:
+        raise FunctionError(_('Error evaluating function: %s') % cstr(e))
 
     anynan = N.any( N.isnan(yvals) )
     if anynan:
@@ -178,9 +181,6 @@ class AxisFunction(axis.Axis):
         self.funcchangeset = -1
         self.boundschangeset = -1
 
-        if type(self) == AxisFunction:
-            self.readDefaults()
-
     @classmethod
     def addSettings(klass, s):
         '''Construct list of settings.'''
@@ -239,7 +239,7 @@ class AxisFunction(axis.Axis):
             return self.cachedfuncobj
         self.funcchangeset = self.document.changeset
 
-        compiled = self.document.compileCheckedExpression(
+        compiled = self.document.evaluate.compileCheckedExpression(
             self.settings.function.strip())
 
         if compiled is None:
@@ -247,7 +247,7 @@ class AxisFunction(axis.Axis):
         else:
             # a python function for doing the evaluation and handling
             # errors
-            env = self.document.eval_context.copy()
+            env = self.document.evaluate.context.copy()
 
             def function(t):
                 env['t'] = t
@@ -305,6 +305,9 @@ class AxisFunction(axis.Axis):
             return None
         return linked
 
+    def isLinear(self):
+        return False
+
     def computePlottedRange(self, force=False):
         '''Use other axis to compute range.'''
 
@@ -508,7 +511,7 @@ class AxisFunction(axis.Axis):
 
     def _linearInterpolWarning(self, vals, xcoords, ycoords):
         '''Linear interpolation, giving out of bounds warning.'''
-        if any(vals < xcoords[0]) or any(vals > xcoords[-1]):
+        if N.any(vals < xcoords[0]) or N.any(vals > xcoords[-1]):
             self.document.log(
                 _('Warning: values exceed bounds in axis-function'))
 
